@@ -18,7 +18,7 @@
 # references.
 # Report from Richard Boulton.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
 AM_CONDITIONAL([COND1], [true])
