@@ -16,10 +16,10 @@
 
 # Test to make sure config headers in subdirectories are cleaned.
 
-. test-init.sh
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
-AC_CONFIG_HEADERS([sub/config.h:sub/config.hin])
+AM_CONFIG_HEADER([sub/config.h:sub/config.hin])
 AC_OUTPUT
 END
 
